@@ -1,4 +1,4 @@
-# Time-stamp: <2012-10-03 16:00:49 Tao Liu>
+# Time-stamp: <2013-05-28 10:56:36 Tao Liu>
 
 """Description: MACS 2 main executable
 
@@ -67,10 +67,10 @@ def run( args ):
     ofile_prefix = options.name
     
     # check if tag files exist
-    with open(options.t1bdg) as file: pass
-    with open(options.c1bdg) as file: pass
-    with open(options.t2bdg) as file: pass
-    with open(options.c2bdg) as file: pass
+    with open(options.t1bdg) as f: pass
+    with open(options.c1bdg) as f: pass
+    with open(options.t2bdg) as f: pass
+    with open(options.c2bdg) as f: pass
     
     if not options.peaks1 == '':
         info("Read peaks for condition 1...")
@@ -93,8 +93,13 @@ def run( args ):
     c1bio = cBedGraphIO.bedGraphIO(options.c1bdg)
     c1btrack = c1bio.build_bdgtrack()
 
-    depth = options.depth
-
+    if len(options.depth) >=2:
+        depth1 = options.depth[0]
+        depth2 = options.depth[1]
+    else:
+        depth1 = options.depth[0]
+        depth2 = depth1
+    
     info("Read and build treatment 2 bedGraph...")
     t2bio = cBedGraphIO.bedGraphIO(options.t2bdg)
     t2btrack = t2bio.build_bdgtrack()
@@ -109,7 +114,7 @@ def run( args ):
                                              c1btrack,
                                              t2btrack,
                                              c2btrack,
-                                             depth, depth )
+                                             depth1, depth2 )
     diffscore.finalize()
     if options.call_peaks:
         diffscore.set_track_score_method(options.track_score_method)
@@ -164,7 +169,7 @@ def run( args ):
         ofhd_xls2.write("# This file is generated by MACS version, using the diffpeak module %s\n" % (MACS_VERSION))
         ofhd_xls2.write(options.argtxt+"\n")
         diffscore.write_peaks_by_summit(ofhd_xls1, ofhd_xls2,
-                        name = options.name, name_prefix="%s_peak_")
+                                        name = options.name, name_prefix="%s_peak_")
         ofhd_xls1.close()
         ofhd_xls2.close()
     
